@@ -1073,7 +1073,7 @@ void GraphExporter::buildGraph(TraceFunction* f, int depth, bool toCallees,
 		// from here with full incl. cost because of previous cutoffs
 		if ((e.cost >= _realCallLimit) && (oldCost < _realCallLimit))
 			cost = e.cost;
-		if (cost < _realCallLimit) {
+		if ((cost <= 0) || (cost <= _realCallLimit)) {
 			if (0)
 				qDebug("  Edge Cutoff, limit not reached");
 			continue;
@@ -1085,7 +1085,10 @@ void GraphExporter::buildGraph(TraceFunction* f, int depth, bool toCallees,
 		else
 			s = f2->inclusive()->subCost(_eventType);
 		SubCost v = call->subCost(_eventType);
-		// FIXME: Can s be 0?
+
+		// Never recurse if s or v is 0 (can happen with bogus input)
+		if ((v == 0) || (s== 0)) continue;
+
 		buildGraph(f2, depth+1, toCallees, factor * v / s);
 	}
 }
@@ -1289,26 +1292,24 @@ CanvasEdgeLabel::CanvasEdgeLabel(CallGraphView* v, CanvasEdge* ce, int x,
 	else
 		setText(1, SubCost(e->cost).pretty());
 
-	setPosition(0, DrawParams::TopCenter);
-	SubCost count((e->count < 1.0) ? 1.0 : e->count);
-	setText(0, QString("%1 x").arg(count.pretty()));
-	setPixmap(0, percentagePixmap(25, 10, (int)(inclP+.5), Qt::blue, true));
+    int pixPos = 1;
+    if (((TraceItemView*)_view)->data()->maxCallCount() > 0) {
+        setPosition(0, DrawParams::TopCenter);
+        SubCost count((e->count < 1.0) ? 1.0 : e->count);
+        setText(0, QString("%1 x").arg(count.pretty()));
+        pixPos = 0;
+        setToolTip(QString("%1 (%2)").arg(text(0)).arg(text(1)));
+    }
+    setPixmap(pixPos, percentagePixmap(25, 10, (int)(inclP+.5), Qt::blue, true));
 
 	_percentage = inclP;
 	if (_percentage > 100.0) _percentage = 100.0;
 
-	if (e->call() && (e->call()->isRecursion() || e->call()->inCycle())) {
-		QString icon = "edit-undo";
-#if 0
-		KIconLoader* loader = KIconLoader::global();
-		QPixmap p= loader->loadIcon(icon, KIconLoader::Small, 0,
-		                            KIconLoader::DefaultState, QStringList(), 0,
-		                            true);
-		setPixmap(0, p);
-#endif
-	}
-
-	setToolTip(QString("%1 (%2)").arg(text(0)).arg(text(1)));
+    if (e->call() && (e->call()->isRecursion() || e->call()->inCycle())) {
+        QFontMetrics fm(font());
+        QPixmap p = QIcon::fromTheme(QString("edit-undo")).pixmap(fm.height());
+        setPixmap(pixPos, p); // replace percentage pixmap
+    }
 }
 
 void CanvasEdgeLabel::paint(QPainter* p,
