@@ -147,13 +147,8 @@ void CallItem::updateCost()
 
     QPixmap p;
     if (sameCycle && !selectedIsCycle && !shownIsCycle) {
-
-	QString icon = "edit-undo";
-#if 0 // TODO
-	KIconLoader* loader = KIconLoader::global();
-	p= loader->loadIcon(icon, KIconLoader::Small, 0,
-			    KIconLoader::DefaultState, QStringList(), 0, true);
-#endif
+        QFontMetrics fm(font(4));
+        p = QIcon::fromTheme(QString("edit-undo")).pixmap(fm.height());
     }
     setIcon(4, p);
 }
